@@ -3,4 +3,4 @@ from PaperCrawlerUtil.crawler_util import *
 from PaperCrawlerUtil.document_util import *
 
 
-basic_config(logs_style=LOG_STYLE_PRINT)
+basic_config(logs_style=LOG_STYLE_PRINT, require_crawler_proxy=True)
