@@ -4,11 +4,10 @@ import random
 import time
 from types import TracebackType
 from typing import Optional
-
 import requests
 
 PROXY_POOL_URL = ""
-logging.basicConfig(filename='../my.log', level=logging.WARNING)
+logging.basicConfig(filename='../../my.log', level=logging.WARNING)
 log_style = "log"
 
 EQUAL = "equal"
@@ -34,9 +33,17 @@ def log(string):
 
 def basic_config(log_file_name="../my.log", log_level=logging.WARNING,
                  proxy_pool_url="",
-                 logs_style=LOG_STYLE_PRINT):
+                 logs_style=LOG_STYLE_PRINT,
+                 require_crawler_proxy=False,
+                 redis_host="127.0.0.1",
+                 redis_port=6379,
+                 redis_database=0):
     """
 
+    :param redis_database:
+    :param redis_port:
+    :param redis_host:
+    :param require_crawler_proxy: 是否需要开启爬虫爬取代理ip
     :param log_file_name: 日志文件名称
     :param log_level: 日志等级
     :param proxy_pool_url: 代理获取地址
@@ -47,6 +54,11 @@ def basic_config(log_file_name="../my.log", log_level=logging.WARNING,
     global log_style
     PROXY_POOL_URL = proxy_pool_url
     log_style = logs_style
+    # if require_crawler_proxy and len(redis_host) > 0 and 65535 >= redis_port >= 0 and 65535 >= redis_database >= 0:
+    #     try:
+    #         Scheduler().run()
+    #     except Exception as e:
+    #         log("代理爬虫异常，请检查redis配置：{}".format(e))
 
 
 def get_split(lens=20, style='='):
