@@ -1,8 +1,6 @@
-import time
 import urllib
 from urllib.request import urlretrieve
 
-import requests
 from bs4 import BeautifulSoup
 from fake_useragent import UserAgent
 
